@@ -1,4 +1,4 @@
-/* $Id: netload.h,v 1.21 2004/07/17 12:09:01 bdejean Exp $ */
+/* $Id: netload.h,v 1.22 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -125,16 +125,6 @@ void glibtop_init_netload_s (glibtop *server);
 void glibtop_get_netload_s (glibtop *server, glibtop_netload *buf, const char *interface);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_netload [];
-extern const unsigned glibtop_types_netload [];
-extern const char *glibtop_labels_netload [];
-extern const char *glibtop_descriptions_netload [];
-
-#endif
 
 G_END_DECLS
 
